-- ===========================================================================
--  Project:	Course "Introduction to Databases Systems"
--  Version:	Fall 2020, University of Halle
--  Module:	cd.sql
--  Purpose:	CREATE TABLE Statements for Composer/CD Example Database
--  Last Change: 04.12.2020
--  Language:	Originally Oracle SQL*Plus, now modified to be standard SQL
--  Authors:	Stefan Brass
--  Email:	brass@informatik.uni-halle.de
--  Address:	Universitaet Halle, Inst. f. Informatik, D-06099 Halle, Germany
--  Copyright:	(c) 1991-2020 by Stefan Brass (+ possibly CD Vendors ?)
--  Copying:	See below.
-- ===========================================================================

--  --------------------------------------------------------------------------
--  You may use this program code, but you cannot make me or my University
--  or anybody else liable in any way for any bugs or damage.
--  This program code comes without any guarantee.
--  I am continually trying to improve the code.
--  If you find errors or have improvements, please tell me.
--
--  This was my collection of classical music CDs around 1990.
--
--  The data may be wrong. It may be possible that the CD vendors have a
--  copyright on it. The CDs are old, so it might be more of historical
--  interest. Use the data at your own risk.
--
--  If there should be copyright issues or other legal problems,
--  your license to use the file automatically ends.
--  --------------------------------------------------------------------------

CREATE SCHEMA IF NOT EXISTS komponist_public;

SET search_path TO komponist_public;

BEGIN;

-- ##################################################################

DROP TABLE IF EXISTS SOLIST;
DROP TABLE IF EXISTS AUFNAHME;
DROP TABLE IF EXISTS STUECK;
DROP TABLE IF EXISTS CD;
DROP TABLE IF EXISTS KOMPONIST;

-- ##################################################################

-- In order to make this file compatible with MariaDB 5.5.68,
-- I wrote foreign keys as table constraints, not as column constraints,
-- and added the referenced columns although they are the primary key
-- and the SQL Standard and all other systems permit to leave them out.
-- They are necessary in this version of the MariaDB fork of MySQL.
-- I haven't checked MySQL itself.

-- ##################################################################


CREATE TABLE KOMPONIST(
	KNR       NUMERIC(2)   NOT NULL,
	NAME      VARCHAR(25)  NOT NULL,
	VORNAME   VARCHAR(20),
	GEBOREN   NUMERIC(4),
	GESTORBEN NUMERIC(4),
	CONSTRAINT KNR_EINDEUTIG_IN_KOMPONIST
		PRIMARY KEY(KNR),
	CONSTRAINT KNR_NICHT_NEGATIV
		CHECK(KNR >= 0),
	CONSTRAINT GEBURTSJAHR_GUELTIG
		CHECK(GEBOREN >= 500 AND GEBOREN < 3000),
	CONSTRAINT TODESJAHR_GUELTIG
		CHECK(GESTORBEN >= 500 AND GESTORBEN < 3000)
);

INSERT INTO KOMPONIST VALUES (11,'Händel','Georg Friedrich',1685,1759);
INSERT INTO KOMPONIST VALUES (12,'Prokofiev','Serge',1891,1953);
INSERT INTO KOMPONIST VALUES (13,'Monteverdi','Claudio',1567,1643);
INSERT INTO KOMPONIST VALUES (14,'Dvorak','Antonin',1841,1904);
INSERT INTO KOMPONIST VALUES (15,'Vivaldi','Antonio',1678,1741);
INSERT INTO KOMPONIST VALUES (16,'Mozart','Leopold',1719,1787);
INSERT INTO KOMPONIST VALUES (17,'Biber','Heinrich Ignaz Franz',1644,1704);
INSERT INTO KOMPONIST VALUES (18,'Telemann','Georg Philipp',1681,1767);
INSERT INTO KOMPONIST VALUES (19,'Byrd','William',1543,1623);
INSERT INTO KOMPONIST VALUES (20,'Mozart','Wolfgang Amadeus',1756,1791);
INSERT INTO KOMPONIST VALUES (21,'Beethoven','Ludwig van',1770,1827);
INSERT INTO KOMPONIST VALUES (22,'Bach','Johann Sebastian',1685,1750);
INSERT INTO KOMPONIST VALUES (23,'Mahler','Gustav',1860,1911);
INSERT INTO KOMPONIST VALUES (24,'Sibelius','Jean',1865,1957);
INSERT INTO KOMPONIST VALUES (25,'Berlioz','Hector',1803,1869);
INSERT INTO KOMPONIST VALUES (26,'Hayden','Joseph',1732,1809);
INSERT INTO KOMPONIST VALUES (27,'Tschaikowsky','Peter',1840,1893);
INSERT INTO KOMPONIST VALUES (28,'Mendelssohn Bartholdy','Felix',1809,1847);
INSERT INTO KOMPONIST VALUES (29,'Schubert','Franz',1797,1828);
INSERT INTO KOMPONIST VALUES (30,'Orff','Carl',1895,null);
INSERT INTO KOMPONIST VALUES (31,'Schostakowitsch','Dmitri',1906,1975);
INSERT INTO KOMPONIST VALUES (32,'Desprez','Josquin',1440,1521);
INSERT INTO KOMPONIST VALUES (33,'Wolf-Ferrari','Ermanno',1876,1948);
INSERT INTO KOMPONIST VALUES (34,'Brahms','Johannes',1833,1897);
INSERT INTO KOMPONIST VALUES (35,'Marcello','Benedetto',1686,1739);
INSERT INTO KOMPONIST VALUES (36,'Leclair','Lean-Marie',1697,1764);
INSERT INTO KOMPONIST VALUES (37,'Corelli','Arcangelo',1653,1713);
INSERT INTO KOMPONIST VALUES (38,'Albinoni','Tommaso',1671,1750);
INSERT INTO KOMPONIST VALUES (39,'Scarlatti','Domenico',1685,1757);
INSERT INTO KOMPONIST VALUES (40,'Manfredini','Francesco',1680,1748);
INSERT INTO KOMPONIST VALUES (41,'Locatelli','Pietro',1695,1764);
INSERT INTO KOMPONIST VALUES (42,'Franck','Melchior',1580,1639);
INSERT INTO KOMPONIST VALUES (43,'Heselloher','Hans',1420,1485);
INSERT INTO KOMPONIST VALUES (44,'Mainerio','Giorgio',1545,1582);
INSERT INTO KOMPONIST VALUES (45,'Fogliano','Giacomo',1468,1548);
INSERT INTO KOMPONIST VALUES (46,'Isaak','Heinrich',1450,1517);
INSERT INTO KOMPONIST VALUES (47,'Da Nola','Giovan Domenico',1510,1592);
INSERT INTO KOMPONIST VALUES (48,'Azzaiolo','Filippo',1530,1569);
INSERT INTO KOMPONIST VALUES (49,'Susato','Tilman',1500,1561);
INSERT INTO KOMPONIST VALUES (50,'Janequin','Clement',1485,1558);

-- ************************************************************************

CREATE TABLE STUECK(
	SNR    NUMERIC(4) NOT NULL,
	KNR    NUMERIC(2),
	TITEL  VARCHAR(45) NOT NULL,
	TONART VARCHAR(7),
	OPUS   VARCHAR(15),
	CONSTRAINT SNR_EINDEUTIG_IN_STUECK
		PRIMARY KEY(SNR),
	CONSTRAINT SNR_NICHT_NEGATIV
		CHECK(SNR >= 0),
	CONSTRAINT STUECK_REF_KOMPONIST
		FOREIGN KEY(KNR) REFERENCES KOMPONIST(KNR)
);

INSERT INTO STUECK VALUES
(1001,11,'Concerto grosso op.6 Nr.7','B-dur','Op.6 Nr.7');
INSERT INTO STUECK VALUES
(1002,11,'Feuerwerks-Musik (Concerto grosso)','D-dur',null);
INSERT INTO STUECK VALUES
(1003,11,'Concerto grosso op.6 Nr.8','c-moll','Op.6 Nr.8');
INSERT INTO STUECK VALUES
(1004,11,'Sinfonia e-moll (aus `Der Messias'')','e-moll',null);
INSERT INTO STUECK VALUES
(1005,12,'Konzert fuer Violine und Orchester Nr.1','D-dur','Op.19');
INSERT INTO STUECK VALUES
(1006,12,'Konzert fuer Violine und Orchester Nr.2','g-moll','Op.63');
INSERT INTO STUECK VALUES
(1007,13,'Verspro Della Beata Vergine',null,null);
INSERT INTO STUECK VALUES
(1008,14,'Slawische Taenze op.46',null,'Op.46 Nr.1-8');
INSERT INTO STUECK VALUES
(1009,14,'Slawische Taenze op.72',null,'Op.72 Nr.1-8');
INSERT INTO STUECK VALUES
(1010,15,'Der Fruehling','E-dur','Op.8 Nr.1 RV269');
INSERT INTO STUECK VALUES
(1011,15,'Der Sommer','g-moll','Op.8 Nr.2 RV315');
INSERT INTO STUECK VALUES
(1012,15,'Der Herbst','F-dur','Op.8 Nr.3 RV293');
INSERT INTO STUECK VALUES
(1013,15,'Der Winter','f-moll','Op.8 Nr.4 RV297');
INSERT INTO STUECK VALUES
(1014,16,'Sinfonia D-Dur mit Dudelsack und Drehleier','D-dur',null);
INSERT INTO STUECK VALUES
(1015,17,'Serenada C-Dur mit dem Nachwächterlied','C-dur',null);
INSERT INTO STUECK VALUES
(1016,null,'Kleine Stücke für Dudelsack und Drehleier',null,null);
INSERT INTO STUECK VALUES
(1017,15,'Concerto per archi e cembalo','G-dur',null);
INSERT INTO STUECK VALUES
(1018,15,'Sinfonia C-Dur','C-dur',null);
INSERT INTO STUECK VALUES
(1019,15,'Concerto per violino e archi','a-moll','Op.3 Nr.6');
INSERT INTO STUECK VALUES
(1020,17,'Sonata III a 5 Violae',null,null);
INSERT INTO STUECK VALUES
(1021,17,'Sonata prima a 8, 2 Clarini, 6 Violae',null,null);
INSERT INTO STUECK VALUES
(1022,17,'Ballettae a 4 Violettae',null,null);
INSERT INTO STUECK VALUES
(1023,17,'Battalia',null,null);
INSERT INTO STUECK VALUES
(1024,17,'Sonata a 7, 6 Tromb, Tamburin con Organo',null,null);
INSERT INTO STUECK VALUES
(1025,17,'Sonata IV a 5 Violae',null,null);
INSERT INTO STUECK VALUES
(1026,17,'Sonata seconda a 8, 2 Clarini, 6 Violae',null,null);
INSERT INTO STUECK VALUES
(1027,17,'Sonata a 6 (die Pauern Kirchfahrt genandt)',null,null);
INSERT INTO STUECK VALUES
(1028,18,'Overture in D (2 Trompeten, Pauken, ...)','D-dur',null);
INSERT INTO STUECK VALUES
(1029,18,'Concerto in D (3 Trompeten, Pauken, Oboen,..)','D-dur',null);
INSERT INTO STUECK VALUES
(1030,18,'Sinfonia in F (Trompete, 3 Posaunen, ...)','F-dur',null);
INSERT INTO STUECK VALUES
(1031,18,'Concerto in D (Trompete, 2 Oboen, continuo)','D-dur',null);
INSERT INTO STUECK VALUES
(1032,18,'Concerto in D (Trompete, 2 Oboen, ...)','D-dur',null);
INSERT INTO STUECK VALUES
(1033,18,'Concerto in D (Trompete, Streicher, continuo)','D-dur',null);
INSERT INTO STUECK VALUES
(1034,18,'Concerto in D (Trompete, Streicher, continuo)','D-dur',null);
INSERT INTO STUECK VALUES
(1035,18,'Suite in D (Trompete, Streicher, continuo)','D-dur',null);
INSERT INTO STUECK VALUES
(1036,18,'Concerto in Es (2 Trompeten, Streicher, cont)','Es-dur',null);
INSERT INTO STUECK VALUES
(1037,19,'Mass for five voices',null,null);
INSERT INTO STUECK VALUES
(1038,19,'Mass for four voices',null,null);
INSERT INTO STUECK VALUES
(1039,19,'Mass for three voices',null,null);
INSERT INTO STUECK VALUES
(1040,19,'Ave verum corpus',null,null);
INSERT INTO STUECK VALUES
(1041,21,'Die Geschöpfe des Prometheus, Ouvertüre',null,'Op.43');
INSERT INTO STUECK VALUES
(1042,20,'Die Entführung aus dem Serail, Ouvertüre',null,'KV 384');
INSERT INTO STUECK VALUES
(1043,21,'Fidelio, Ouvertüre',null,'Op.94');
INSERT INTO STUECK VALUES
(1044,20,'Die Zauberflöte, Ouvertüre',null,'KV 620');
INSERT INTO STUECK VALUES
(1045,21,'Egmont, Ouvertüre',null,'Op.84');
INSERT INTO STUECK VALUES
(1046,20,'Die Hochzeit des Figaro, Ouvertüre',null,'KV 492');
INSERT INTO STUECK VALUES
(1047,21,'Leonore III, Ouvertüre',null,'Op.72b');
INSERT INTO STUECK VALUES
(1048,20,'Titus, Ouvertüre',null,'KV 621');
INSERT INTO STUECK VALUES
(1049,21,'Coriolan, Ouvertüre',null,'Op.62');
INSERT INTO STUECK VALUES
(1050,13,'Cantate Domine - Motet',null,null);
INSERT INTO STUECK VALUES
(1051,13,'Mass for four voices (1650)',null,null);
INSERT INTO STUECK VALUES
(1052,13,'Domine, ne in furore - Motet',null,null);
INSERT INTO STUECK VALUES
(1053,13,'Mass `In illo tempore'' for six voices (1610)',null,null);
INSERT INTO STUECK VALUES
(1054,22,'Violin Concerto a-minor','a-moll','BWV 1041');
INSERT INTO STUECK VALUES
(1055,22,'Violin Concerto E-major','E-dur','BWV 1042');
INSERT INTO STUECK VALUES
(1056,22,'Concerto d-minor for 2 Violins','d-moll','BWV 1043');
INSERT INTO STUECK VALUES
(1057,22,'Konzert d-minor for Oboe and Violin','d-moll','BWV 1060');
INSERT INTO STUECK VALUES
(1058,12,'Symphonie Nr.1 D-dur `Symphonie classique''','D-dur','Op.25');
INSERT INTO STUECK VALUES
(1059,12,'Symphonie Nr.5 B-dur','B-dur','Op.100');
INSERT INTO STUECK VALUES
(1060,23,'Sinfonie Nr.4 G-dur','G-dur',null);
INSERT INTO STUECK VALUES
(1061,24,'Symphonie Nr.2 D-dur','D-dur','Op.43');
INSERT INTO STUECK VALUES
(1062,24,'`Finlandia''',null,'Op.26');
INSERT INTO STUECK VALUES
(1063,24,'`Valse triste''',null,'Op.44');
INSERT INTO STUECK VALUES
(1064,24,'`The Swan of Tuonela''',null,'Op.22 Nr.2');
INSERT INTO STUECK VALUES
(1065,11,'Wassermusik, Suite in F-dur','F-dur',null);
INSERT INTO STUECK VALUES
(1066,11,'Wassermusik, Suite in D/G-dur',null,null);
INSERT INTO STUECK VALUES
(1067,11,'Concerto a due cori no.2',null,null);
INSERT INTO STUECK VALUES
(1068,11,'Concerto a due cori no.3',null,null);
INSERT INTO STUECK VALUES
(1069,11,'Concerto grosso op.3 Nr.1','B-dur','Op.3 Nr.1');
INSERT INTO STUECK VALUES
(1070,11,'Concerto grosso op.3 Nr.2','B-dur','Op.3 Nr.2');
INSERT INTO STUECK VALUES
(1071,11,'Concerto grosso op.3 Nr.3','G-dur','Op.3 Nr.3');
INSERT INTO STUECK VALUES
(1072,11,'Concerto grosso op.3 Nr.4','F-dur','Op.3 Nr.4');
INSERT INTO STUECK VALUES
(1073,11,'Concerto grosso op.3 Nr.5','d-moll','Op.3 Nr.5');
INSERT INTO STUECK VALUES
(1074,11,'Concerto grosso op.3 Nr.6','D-dur','Op.3 Nr.6');
INSERT INTO STUECK VALUES
(1075,11,'Concerto grosso op.6 Nr.1','G-dur','Op.6 Nr.1');
INSERT INTO STUECK VALUES
(1076,11,'Concerto grosso op.6 Nr.2','F-dur','Op.6 Nr.2');
INSERT INTO STUECK VALUES
(1077,11,'Concerto grosso op.6 Nr.3','e-moll','Op.6 Nr.3');
INSERT INTO STUECK VALUES
(1078,11,'Concerto grosso op.6 Nr.4','a-moll','Op.6 Nr.4');
INSERT INTO STUECK VALUES
(1079,11,'Concerto grosso op.6 Nr.5','D-dur','Op.6 Nr.5');
INSERT INTO STUECK VALUES
(1080,11,'Concerto grosso op.6 Nr.6','g-moll','Op.6 Nr.6');
INSERT INTO STUECK VALUES
(1081,11,'Concerto grosso op.6 Nr.9','F-dur','Op.6 Nr.9');
INSERT INTO STUECK VALUES
(1082,11,'Concerto grosso op.6 Nr.10','d-moll','Op.6 Nr.10');
INSERT INTO STUECK VALUES
(1083,11,'Concerto grosso op.6 Nr.11','A-dur','Op.6 Nr.11');
INSERT INTO STUECK VALUES
(1084,11,'Concerto grosso op.6 Nr.12','b-moll','Op.6 Nr.12');
INSERT INTO STUECK VALUES
(1085,25,'Symphonie Fantastique',null,'Op.14a');
INSERT INTO STUECK VALUES
(1086,25,'Harold in Italy',null,'Op.16');
INSERT INTO STUECK VALUES
(1087,25,'Overture - Rob Roy',null,null);
INSERT INTO STUECK VALUES
(1088,25,'Overture - The Corsair',null,'Op.21');
INSERT INTO STUECK VALUES
(1089,12,'Cinderella (Suite)',null,null);
INSERT INTO STUECK VALUES
(1090,16,'Hornkonzert D-dur','D-dur','KV 386b 412/514');
INSERT INTO STUECK VALUES
(1091,16,'Hornkonzert Es-dur','Es-dur','KV 495');
INSERT INTO STUECK VALUES
(1092,16,'Rondo in Es-dur','Es-dur','KV 371');
INSERT INTO STUECK VALUES
(1093,16,'Hornkonzert Es-dur','Es-dur','KV 447');
INSERT INTO STUECK VALUES
(1094,16,'Hornkonzert Es-dur','Es-dur','KV 417');
INSERT INTO STUECK VALUES
(1095,26,'Cellokonzert C-dur','C-dur','Hob. VIIb: 1');
INSERT INTO STUECK VALUES
(1096,26,'Cellokonzert D-dur','D-dur','Hob. VIIb: 2');
INSERT INTO STUECK VALUES
(1097,18,'Violinkonzert Nr.4','E-dur',null);
INSERT INTO STUECK VALUES
(1098,18,'Violinkonzert Nr.11','B-dur',null);
INSERT INTO STUECK VALUES
(1099,18,'Violinkonzert Nr.8','G-dur',null);
INSERT INTO STUECK VALUES
(1100,18,'Violinkonzert Nr.3','D-dur',null);
INSERT INTO STUECK VALUES
(1101,18,'Violinkonzert Nr.9','g-moll',null);
INSERT INTO STUECK VALUES
(1102,20,'Missa in c `Grosse Messe''','c-moll','KV 427 (417a)');
INSERT INTO STUECK VALUES
(1103,27,'Konzert für Violine und Orchester D-dur','D-dur','Op.35');
INSERT INTO STUECK VALUES
(1104,28,'Konzert für Violine und Orchester e-moll','e-moll','Op.64');
INSERT INTO STUECK VALUES
(1105,22,'Brandenburgisches Konzert Nr.1','F-dur','BWV 1046');
INSERT INTO STUECK VALUES
(1106,22,'Brandenburgisches Konzert Nr.2','F-dur','BWV 1047');
INSERT INTO STUECK VALUES
(1107,22,'Brandenburgisches Konzert Nr.3','G-dur','BWV 1048');
INSERT INTO STUECK VALUES
(1108,22,'Brandenburgisches Konzert Nr.4','G-dur','BWV 1049');
INSERT INTO STUECK VALUES
(1109,22,'Brandenburgisches Konzert Nr.5','D-dur','BWV 1050');
INSERT INTO STUECK VALUES
(1110,22,'Brandenburgisches Konzert Nr.6','B-dur','BWV 1051');
INSERT INTO STUECK VALUES
(1111,29,'Symphonie Nr.8 `Die Unvollendete''','h-moll','D.759');
INSERT INTO STUECK VALUES
(1112,29,'Symphonie Nr.5','B-dur','D.485');
INSERT INTO STUECK VALUES
(1113,29,'7 Walzer (aus Valses nobles op.77)',null,'D.969');
INSERT INTO STUECK VALUES
(1114,29,'Deutscher Tanz','C-dur','Op.33');
INSERT INTO STUECK VALUES
(1115,30,'Die Kluge',null,null);
INSERT INTO STUECK VALUES
(1116,30,'Der Mond',null,null);
INSERT INTO STUECK VALUES
(1117,12,'The Love of the Three Oranges: Symponic Suite',null,'Op.33a');
INSERT INTO STUECK VALUES
(1118,12,'Lieutenant Kije: Symponic Suite',null,'Op.60');
INSERT INTO STUECK VALUES
(1119,12,'Symphonie Nr.7',null,'Op.131');
INSERT INTO STUECK VALUES
(1120,12,'Symphonie Nr.6',null,'Op.111');
INSERT INTO STUECK VALUES
(1121,12,'Symphonie Nr.4 (1930)',null,'Op.47');
INSERT INTO STUECK VALUES
(1122,12,'Symphonie Nr.4 (1947)',null,'Op.112');
INSERT INTO STUECK VALUES
(1123,12,'Symphonie Nr.2',null,'Op.40');
INSERT INTO STUECK VALUES
(1124,12,'Symphonie Nr.3',null,'Op.44');
INSERT INTO STUECK VALUES
(1125,31,'Symphonie Nr.9','Es-dur','Op.70');
INSERT INTO STUECK VALUES
(1126,31,'Symphonie Nr.12 `1917''','d-moll','Op.112');
INSERT INTO STUECK VALUES
(1127,13,'Madrigali Amorosi (Liebeslieder)',null,null);
INSERT INTO STUECK VALUES
(1128,13,'Madrigali Guerrieri (Landskechtslieder)',null,null);
INSERT INTO STUECK VALUES
(1129,32,'Missa di dadi',null,null);
INSERT INTO STUECK VALUES
(1130,32,'Missa `Faisant regretz''',null,null);
INSERT INTO STUECK VALUES
(1131,33,'Klaviertrio Nr.1','D-dur','Op.5');
INSERT INTO STUECK VALUES
(1132,33,'Klaviertrio Nr.2','Fis-dur','Op.7');
INSERT INTO STUECK VALUES
(1133,33,'Klavierquintett','Des-dur','Op.6');
INSERT INTO STUECK VALUES
(1134,33,'Streichquintett','C-dur','Op.24');
INSERT INTO STUECK VALUES
(1135,34,'Ungarische Tänze Nr.1,3,10,17-21',null,null);
INSERT INTO STUECK VALUES
(1136,34,'Symphonie Nr.2','D-dur','Op.73');
INSERT INTO STUECK VALUES
(1137,11,'`Messias'' (Höhepunkte)',null,null);
INSERT INTO STUECK VALUES
(1138,20,'`Salzburger Sinfonie'' Nr.1','D-dur','KV 136');
INSERT INTO STUECK VALUES
(1139,20,'`Salzburger Sinfonie'' Nr.2','B-dur','KV 137');
INSERT INTO STUECK VALUES
(1140,20,'`Salzburger Sinfonie'' Nr.3','F-dur','KV 138');
INSERT INTO STUECK VALUES
(1141,20,'`Eine kleine Nachtmusik''','G-dur','KV 525');
INSERT INTO STUECK VALUES
(1142,15,'Oboenkonzert a-moll','a-moll',null);
INSERT INTO STUECK VALUES
(1143,35,'Oboenkonzert d-moll','d-moll',null);
INSERT INTO STUECK VALUES
(1144,18,'Oboenkonzert c-moll','c-moll',null);
INSERT INTO STUECK VALUES
(1145,36,'Oboenkonzert C-dur','C-dur',null);
INSERT INTO STUECK VALUES
(1146,37,'Concerto grosso op.6/8','g-moll','Op.6/8');
INSERT INTO STUECK VALUES
(1147,38,'Concerto a cinque','B-dur',null);
INSERT INTO STUECK VALUES
(1148,39,'Sonata f-moll','f-moll',null);
INSERT INTO STUECK VALUES
(1149,40,'Concerto grosso op.3/12','C-dur','Op.3/12');
INSERT INTO STUECK VALUES
(1150,41,'Concerto grosso op.1/8','f-moll','Op.1/8');
INSERT INTO STUECK VALUES
(1151,39,'Sonata G-dur','G-dur',null);
INSERT INTO STUECK VALUES
(1152,37,'Concerto grosso D-dur','D-dur',null);
INSERT INTO STUECK VALUES
(1153,13,'L''Orfeo',null,null);
INSERT INTO STUECK VALUES
(1154,13,'Il Ritorno d''Ulisse in Patria',null,null);
INSERT INTO STUECK VALUES
(1155,13,'L''Incoronazione di Poppea',null,null);
INSERT INTO STUECK VALUES
(1156,42,'Intrada',null,null);
INSERT INTO STUECK VALUES
(1157,43,'Von üppiklichen Dingen',null,null);
INSERT INTO STUECK VALUES
(1158,44,'Ballo francese',null,null);
INSERT INTO STUECK VALUES
(1159,45,'L''armor, dona, ch''io te porto',null,null);
INSERT INTO STUECK VALUES
(1160,null,'Mit ganzem Willen (ca.1460)',null,null);
INSERT INTO STUECK VALUES
(1161,46,'Questo mostrarsi adirata di fore',null,null);
INSERT INTO STUECK VALUES
(1162,null,'Passamezzo antico `Caminata'' (ca.1510)',null,null);
INSERT INTO STUECK VALUES
(1163,null,'Es hett ein schwab ein töchterlein (ca.1530)',null,null);
INSERT INTO STUECK VALUES
(1164,46,'Fortuna desperata',null,null);
INSERT INTO STUECK VALUES
(1165,null,'Il marchese do Soluzzo (ca.1550)',null,null);
INSERT INTO STUECK VALUES
(1166,null,'Merce te chiamo (15.Jh.)',null,null);
INSERT INTO STUECK VALUES
(1167,47,'Madonna nui sapimo',null,null);
INSERT INTO STUECK VALUES
(1168,46,'Maudit soit',null,null);
INSERT INTO STUECK VALUES
(1169,null,'Passamezzo moderno (ca.1510)',null,null);
INSERT INTO STUECK VALUES
(1170,47,'Chi la gagliarda',null,null);
INSERT INTO STUECK VALUES
(1171,null,'Der heilig herr sanct Matheis (ca.1515)',null,null);
INSERT INTO STUECK VALUES
(1172,45,'Io vorrei dio d''amore',null,null);
INSERT INTO STUECK VALUES
(1173,50,'Il estoit une filette',null,null);
INSERT INTO STUECK VALUES
(1174,null,'Rodrigo Martines (ca.1500)',null,null);
INSERT INTO STUECK VALUES
(1175,null,'Dindirindin',null,null);
INSERT INTO STUECK VALUES
(1176,32,'Scaramella',null,null);
INSERT INTO STUECK VALUES
(1177,48,'Ti parti cor mio caro',null,null);
INSERT INTO STUECK VALUES
(1178,49,'Bergerette Sans roch',null,null);

-- ************************************************************************

CREATE TABLE CD(
	CDNR            NUMERIC(3)  NOT NULL,
	NAME            VARCHAR(45) NOT NULL,
	HERSTELLER      VARCHAR(17),
	ANZ_CDS         NUMERIC(2),
	GESAMTSPIELZEIT NUMERIC(3),
	CONSTRAINT CDNR_EINDEUTIG_IN_CD
		PRIMARY KEY(CDNR),
	CONSTRAINT CDNR_NICHT_NEGATIV
		CHECK(CDNR >= 0),
	CONSTRAINT ANZ_CDS_POSITIV
		CHECK(ANZ_CDS >= 1),
	CONSTRAINT SPIELZEIT_POSITIV
		CHECK(GESAMTSPIELZEIT >= 1)
);

INSERT INTO CD
VALUES (101,'Händel: Feuerwerksmusik','zyx classic',1,60);
INSERT INTO CD
VALUES (102,'Serge Prokofiev: Die Violinkonzerte','DG',1,49);
INSERT INTO CD
VALUES (103,'Monteverdi: Vespro Della Beata Vergine 1610','Decca',2,100);
INSERT INTO CD
VALUES (104,'Antonin Dvorak: Slawische Tänze','DG',1,70);
INSERT INTO CD
VALUES (105,'Vivaldi: Le Quattro Stagioni (I Musici)','Philips',1,42);
INSERT INTO CD
VALUES (106,'Leopold Mozart: Sinfonia D-Dur ...','Orfeo',1,44);
INSERT INTO CD
VALUES (107,'Vivaldi: Die vier Jahreszeiten','zyx classic',1,64);
INSERT INTO CD
VALUES (108,'Heinrich Ignaz Franz Biber: Battalia ...','Teldec',1,51);
INSERT INTO CD
VALUES (109,'Telemann: Trompetenkonzerte','Nimbus Records',1,76);
INSERT INTO CD
VALUES (110,'William Byrd: The Three Masses','Gimell',1,67);
INSERT INTO CD
VALUES (111,'Mozart/Beethoven: Klassische Ouvertüren','zyx classic',1,64);
INSERT INTO CD
VALUES (112,'Monteverdi: Mass for four voices, ...','Hyperion',1,57);
INSERT INTO CD
VALUES (113,'Bach: Violinkonzerte','Philips',1,61);
INSERT INTO CD
VALUES (114,'Sergej Prokofiew: Symphonie Classique ...','DG',1,57);
INSERT INTO CD
VALUES (115,'Gustav Mahler: Sinfonie Nr.4 G-dur','Saphir',1,57);
INSERT INTO CD
VALUES (116,'Sibelius: Symphony No.2 ...','Philips',1,69);
INSERT INTO CD
VALUES (117,'G.F.Handel: Orchesterwerke','Archiv Produktion',6,342);
INSERT INTO CD
VALUES (118,'Berlioz: Symphonie Fantastique','Meastro',1,49);
INSERT INTO CD
VALUES (119,'Berlioz: Harold in Italy','Decca',1,66);
INSERT INTO CD
VALUES (120,'Prokofiev: Cinderella (Suite)','RCA',1,49);
INSERT INTO CD
VALUES (121,'Mozart: Hornkonzerte','Philips',1,60);
INSERT INTO CD
VALUES (122,'Hayden: Cellokonzerte','Philips',1,47);
INSERT INTO CD
VALUES (123,'Telemann: 5 Violinkonzerte','Philips',1,51);
INSERT INTO CD
VALUES (124,'Mozart: Grosse Messe in c-moll','Teldec',1,56);
INSERT INTO CD
VALUES (125,'Tschaikowsky/Mendelssohn: Violinkonzerte','DG',1,58);
INSERT INTO CD
VALUES (126,'Brandenburg Concertos No.1, 3, 4 and 6','Spectrum',1,72);
INSERT INTO CD
VALUES (127,'Brandenburgische Konzerte','zyx classic',1,65);
INSERT INTO CD
VALUES (128,'Schubert: Die Unvollendete','zyx classic',1,64);
INSERT INTO CD
VALUES (129,'Carl Orff: Die Kluge / Der Mond','eurodisc',2,158);
INSERT INTO CD
VALUES (130,'Prokofiev: Classical Symphony ...','EMI',1,53);
INSERT INTO CD
VALUES (131,'Prokofiev: Les Symphonies','ERATO',4,280);
INSERT INTO CD
VALUES (132,'Schostakowitsch: Symphonien 9+12','eurodisc',1,68);
INSERT INTO CD
VALUES (133,'Claudio Monteverdi: Madrigali Amorosi ...','Intercord',1,39);
INSERT INTO CD
VALUES (134,'Josquin Desprez: Missa di dadi ...','L''oiseau-Lyre',1,52);
INSERT INTO CD
VALUES (135,'Wolf-Ferrari: Kammermusik','Dabringhaus/Grimm',2,118);
INSERT INTO CD
VALUES (136,'Brahms: Ungarische Tänze','zyx classic',1,60);
INSERT INTO CD
VALUES (137,'G. F. Händel: `Messias'' (Höhepunkte)','DD classique',1,53);
INSERT INTO CD
VALUES (138,'Mozart: Salzburger Sinfonien','zyx classic',1,61);
INSERT INTO CD
VALUES (139,'Oboenkonzerte','Da Camera Magna',1,43);
INSERT INTO CD
VALUES (140,'Corelli,Albinoni,Scarlatti,Manfredini,...','zyx classic',1,66);
INSERT INTO CD
VALUES (141,'Claudio Monteverdi: L''Orfeo, Ulisse, Poppea','Teldec',6,409);
INSERT INTO CD
VALUES (142,'Schlager um 1500','Christophorus',1,63);

-- ************************************************************************

CREATE TABLE AUFNAHME(
	CDNR      NUMERIC(3) NOT NULL,
	SNR       NUMERIC(4) NOT NULL,
	ORCHESTER VARCHAR(45),
	LEITUNG   VARCHAR(20),
	CONSTRAINT AUFNAHME_SCHLUESSEL
		PRIMARY KEY(CDNR, SNR),
	CONSTRAINT AUFNAHME_REF_STUECK
		FOREIGN KEY (SNR) REFERENCES STUECK(SNR),
	CONSTRAINT AUFNAHME_REF_CD
		FOREIGN KEY(CDNR) REFERENCES CD(CDNR)
);

INSERT INTO AUFNAHME VALUES
(101,1001,'London Festival Orchestra','Sidney Lark');
INSERT INTO AUFNAHME VALUES
(101,1002,'London Festival Orchestra','Sidney Lark');
INSERT INTO AUFNAHME VALUES
(101,1003,'London Festival Orchestra','Sidney Lark');
INSERT INTO AUFNAHME VALUES
(101,1004,'Radio-Sinfonieorchester Stuttgart','Garcia Navarro');
INSERT INTO AUFNAHME VALUES
(102,1005,'Chicago Symphony Orchestra','Claudio Abbado');
INSERT INTO AUFNAHME VALUES
(102,1006,'Chicago Symphony Orchestra','Claudio Abbado');
INSERT INTO AUFNAHME VALUES
(103,1007,'The Monteverdi Choir and Orchestra','John Eliot Gardiner');
INSERT INTO AUFNAHME VALUES
(104,1008,'Symponie-Orchester des Bayerischen Rundfunks','Rafael Kubelik');
INSERT INTO AUFNAHME VALUES
(104,1009,'Symponie-Orchester des Bayerischen Rundfunks','Rafael Kubelik');
INSERT INTO AUFNAHME VALUES
(105,1010,'I Musici',null);
INSERT INTO AUFNAHME VALUES
(105,1011,'I Musici',null);
INSERT INTO AUFNAHME VALUES
(105,1012,'I Musici',null);
INSERT INTO AUFNAHME VALUES
(105,1013,'I Musici',null);
INSERT INTO AUFNAHME VALUES
(106,1014,'Münchner Kammerorchester','Hans Stadlmair');
INSERT INTO AUFNAHME VALUES
(106,1015,'Münchner Kammerorchester','Hans Stadlmair');
INSERT INTO AUFNAHME VALUES
(106,1016,null,null);
INSERT INTO AUFNAHME VALUES
(107,1010,'Südwest-Studioorchester','Heribert Münchner');
INSERT INTO AUFNAHME VALUES
(107,1011,'Südwest-Studioorchester','Heribert Münchner');
INSERT INTO AUFNAHME VALUES
(107,1012,'Südwest-Studioorchester','Heribert Münchner');
INSERT INTO AUFNAHME VALUES
(107,1013,'Südwest-Studioorchester','Heribert Münchner');
INSERT INTO AUFNAHME VALUES
(107,1017,'Die Zagreber Solisten',null);
INSERT INTO AUFNAHME VALUES
(107,1018,'Die Zagreber Solisten',null);
INSERT INTO AUFNAHME VALUES
(107,1019,'Südwest-Studioorchester','Heribert Münchner');
INSERT INTO AUFNAHME VALUES
(108,1020,'Concentus musicus Wien','Nikolaus Harnoncourt');
INSERT INTO AUFNAHME VALUES
(108,1021,'Concentus musicus Wien','Nikolaus Harnoncourt');
INSERT INTO AUFNAHME VALUES
(108,1022,'Concentus musicus Wien','Nikolaus Harnoncourt');
INSERT INTO AUFNAHME VALUES
(108,1023,'Concentus musicus Wien','Nikolaus Harnoncourt');
INSERT INTO AUFNAHME VALUES
(108,1024,'Concentus musicus Wien','Nikolaus Harnoncourt');
INSERT INTO AUFNAHME VALUES
(108,1025,'Concentus musicus Wien','Nikolaus Harnoncourt');
INSERT INTO AUFNAHME VALUES
(108,1026,'Concentus musicus Wien','Nikolaus Harnoncourt');
INSERT INTO AUFNAHME VALUES
(108,1027,'Concentus musicus Wien','Nikolaus Harnoncourt');
INSERT INTO AUFNAHME VALUES
(109,1028,'English String Orchestra','William Boughton');
INSERT INTO AUFNAHME VALUES
(109,1029,'English String Orchestra','William Boughton');
INSERT INTO AUFNAHME VALUES
(109,1030,'English String Orchestra','William Boughton');
INSERT INTO AUFNAHME VALUES
(109,1031,'English String Orchestra','William Boughton');
INSERT INTO AUFNAHME VALUES
(109,1032,'English String Orchestra','William Boughton');
INSERT INTO AUFNAHME VALUES
(109,1033,'English String Orchestra','William Boughton');
INSERT INTO AUFNAHME VALUES
(109,1034,'English String Orchestra','William Boughton');
INSERT INTO AUFNAHME VALUES
(109,1035,'English String Orchestra','William Boughton');
INSERT INTO AUFNAHME VALUES
(109,1036,'English String Orchestra','William Boughton');
INSERT INTO AUFNAHME VALUES
(110,1037,'The Tallis Scholars','Peter Phillips');
INSERT INTO AUFNAHME VALUES
(110,1038,'The Tallis Scholars','Peter Phillips');
INSERT INTO AUFNAHME VALUES
(110,1039,'The Tallis Scholars','Peter Phillips');
INSERT INTO AUFNAHME VALUES
(110,1040,'The Tallis Scholars','Peter Phillips');
INSERT INTO AUFNAHME VALUES
(111,1041,'London Festival Orchestra','Kurt Redel');
INSERT INTO AUFNAHME VALUES
(111,1042,'London Philharmonic Orchestra','Alfred Scholz');
INSERT INTO AUFNAHME VALUES
(111,1043,'Radio Symphonieorchester','Anton Nanut');
INSERT INTO AUFNAHME VALUES
(111,1044,'London Philharmonic Orchestra','Alfred Scholz');
INSERT INTO AUFNAHME VALUES
(111,1045,'London Symphony Orchestra','Alfred Scholz');
INSERT INTO AUFNAHME VALUES
(111,1046,'London Philharmonic Orchestra','Alfred Scholz');
INSERT INTO AUFNAHME VALUES
(111,1047,'Radio Symphonieorchester','Anton Nanut');
INSERT INTO AUFNAHME VALUES
(111,1048,'London Festival Orchestra','Kurt Redel');
INSERT INTO AUFNAHME VALUES
(111,1049,'London Philharmonic Orchestra','Alfred Scholz');
INSERT INTO AUFNAHME VALUES
(112,1050,'The Sixteen','Harry Christophers');
INSERT INTO AUFNAHME VALUES
(112,1051,'The Sixteen','Harry Christophers');
INSERT INTO AUFNAHME VALUES
(112,1052,'The Sixteen','Harry Christophers');
INSERT INTO AUFNAHME VALUES
(112,1053,'The Sixteen','Harry Christophers');
INSERT INTO AUFNAHME VALUES
(113,1054,'Les Solistes Romands','Arpad Gerecz');
INSERT INTO AUFNAHME VALUES
(113,1055,'Les Solistes Romands','Arpad Gerecz');
INSERT INTO AUFNAHME VALUES
(113,1056,'Les Solistes Romands','Arpad Gerecz');
INSERT INTO AUFNAHME VALUES
(113,1057,'New Philharmonia Orchestra','Edo De Waart');
INSERT INTO AUFNAHME VALUES
(114,1058,'Berliner Philharmoniker','Herbert von Karajan');
INSERT INTO AUFNAHME VALUES
(114,1059,'Berliner Philharmoniker','Herbert von Karajan');
INSERT INTO AUFNAHME VALUES
(115,1060,'Sinfonieorchester des Südwestfunks','Michael Gielen');
INSERT INTO AUFNAHME VALUES
(116,1061,'Boston Symphony Orchestra','Sir Colin Davis');
INSERT INTO AUFNAHME VALUES
(116,1062,'Boston Symphony Orchestra','Sir Colin Davis');
INSERT INTO AUFNAHME VALUES
(116,1063,'Boston Symphony Orchestra','Sir Colin Davis');
INSERT INTO AUFNAHME VALUES
(116,1064,'Boston Symphony Orchestra','Sir Colin Davis');
INSERT INTO AUFNAHME VALUES
(117,1065,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1066,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1002,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1067,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1068,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1069,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1070,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1071,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1072,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1073,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1074,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1075,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1076,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1077,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1078,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1079,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1080,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1001,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1003,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1081,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1082,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1083,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(117,1084,'The English Concert','Trevor Pinnock');
INSERT INTO AUFNAHME VALUES
(118,1085,'The Cleveland Orchestra','Lorin Maazel');
INSERT INTO AUFNAHME VALUES
(119,1086,'Orchestre symphonique de Montreal','Charles Dutoit');
INSERT INTO AUFNAHME VALUES
(119,1087,'Orchestre symphonique de Montreal','Charles Dutoit');
INSERT INTO AUFNAHME VALUES
(119,1088,'Orchestre symphonique de Montreal','Charles Dutoit');
INSERT INTO AUFNAHME VALUES
(120,1089,'Saint Louis Symphony Orchestra','Leonard Slatkin');
INSERT INTO AUFNAHME VALUES
(121,1090,'Academy of St.Martin-in-the-Fields','Sir Neville Marriner');
INSERT INTO AUFNAHME VALUES
(121,1091,'Academy of St.Martin-in-the-Fields','Sir Neville Marriner');
INSERT INTO AUFNAHME VALUES
(121,1092,'Academy of St.Martin-in-the-Fields','Sir Neville Marriner');
INSERT INTO AUFNAHME VALUES
(121,1093,'Academy of St.Martin-in-the-Fields','Sir Neville Marriner');
INSERT INTO AUFNAHME VALUES
(121,1094,'Academy of St.Martin-in-the-Fields','Sir Neville Marriner');
INSERT INTO AUFNAHME VALUES
(122,1095,'Academy of St.Martin-in-the-Fields','Sir Neville Marriner');
INSERT INTO AUFNAHME VALUES
(122,1096,'Academy of St.Martin-in-the-Fields','Sir Neville Marriner');
INSERT INTO AUFNAHME VALUES
(123,1097,'Academy of St.Martin-in-the-Fields','Iona Brown');
INSERT INTO AUFNAHME VALUES
(123,1098,'Academy of St.Martin-in-the-Fields','Iona Brown');
INSERT INTO AUFNAHME VALUES
(123,1099,'Academy of St.Martin-in-the-Fields','Iona Brown');
INSERT INTO AUFNAHME VALUES
(123,1100,'Academy of St.Martin-in-the-Fields','Iona Brown');
INSERT INTO AUFNAHME VALUES
(123,1101,'Academy of St.Martin-in-the-Fields','Iona Brown');
INSERT INTO AUFNAHME VALUES
(124,1102,'Concentus musicus Wien','Nikolaus Harnoncourt');
INSERT INTO AUFNAHME VALUES
(125,1103,'Wiener Philharmoniker','Claudio Abbado');
INSERT INTO AUFNAHME VALUES
(125,1104,'Wiener Philharmoniker','Claudio Abbado');
INSERT INTO AUFNAHME VALUES
(126,1105,'Camerata Würzburg','Prof. H. Reinartz');
INSERT INTO AUFNAHME VALUES
(126,1107,'Camerata Würzburg','Prof. H. Reinartz');
INSERT INTO AUFNAHME VALUES
(126,1108,'Camerata Würzburg','Prof. H. Reinartz');
INSERT INTO AUFNAHME VALUES
(126,1110,'Camerata Würzburg','Prof. H. Reinartz');
INSERT INTO AUFNAHME VALUES
(127,1105,'Südwest-Studioorchester','Heribert Münchner');
INSERT INTO AUFNAHME VALUES
(127,1106,'Südwest-Studioorchester','Heribert Münchner');
INSERT INTO AUFNAHME VALUES
(127,1107,'Südwest-Studioorchester','Heribert Münchner');
INSERT INTO AUFNAHME VALUES
(127,1109,'Südwest-Studioorchester','Heribert Münchner');
INSERT INTO AUFNAHME VALUES
(128,1111,'Philharm. Festspielorchester','Vladimir Petroschoff');
INSERT INTO AUFNAHME VALUES
(128,1112,'Philharm. Festspielorchester','Vladimir Petroschoff');
INSERT INTO AUFNAHME VALUES
(128,1113,null,null);
INSERT INTO AUFNAHME VALUES
(128,1114,'Symponisches Orchester Berlin','Carl-August Bünte');
INSERT INTO AUFNAHME VALUES
(129,1115,'Münchner Rundfunkorchester','Kurt Eichhorn');
INSERT INTO AUFNAHME VALUES
(129,1116,'Münchner Rundfunkorchester','Kurt Eichhorn');
INSERT INTO AUFNAHME VALUES
(130,1117,'London Philharmonic Orchestra','Enrique Batiz');
INSERT INTO AUFNAHME VALUES
(130,1058,'London Philharmonic Orchestra','Enrique Batiz');
INSERT INTO AUFNAHME VALUES
(130,1118,'London Philharmonic Orchestra','Enrique Batiz');
INSERT INTO AUFNAHME VALUES
(131,1058,'Orchestre National De France','M. Rostropovitch');
INSERT INTO AUFNAHME VALUES
(131,1059,'Orchestre National De France','M. Rostropovitch');
INSERT INTO AUFNAHME VALUES
(131,1119,'Orchestre National De France','M. Rostropovitch');
INSERT INTO AUFNAHME VALUES
(131,1120,'Orchestre National De France','M. Rostropovitch');
INSERT INTO AUFNAHME VALUES
(131,1121,'Orchestre National De France','M. Rostropovitch');
INSERT INTO AUFNAHME VALUES
(131,1122,'Orchestre National De France','M. Rostropovitch');
INSERT INTO AUFNAHME VALUES
(131,1123,'Orchestre National De France','M. Rostropovitch');
INSERT INTO AUFNAHME VALUES
(131,1124,'Orchestre National De France','M. Rostropovitch');
INSERT INTO AUFNAHME VALUES
(132,1125,'Staatl. Sinfonie-Orch. des Kultusmin.d.UdSSR','G. Roshdestwenskij');
INSERT INTO AUFNAHME VALUES
(132,1126,'Staatl. Sinfonie-Orch. des Kultusmin.d.UdSSR','G. Roshdestwenskij');
INSERT INTO AUFNAHME VALUES
(133,1127,'Die Prager Madrigalisten/Musica Antiqua Wien','Venhoda/Clemencic');
INSERT INTO AUFNAHME VALUES
(133,1128,'Die Prager Madrigalisten/Musica Antiqua Wien','Venhoda/Clemencic');
INSERT INTO AUFNAHME VALUES
(134,1129,'The Medieval Ensemble of London','P.Davies/T.Davies');
INSERT INTO AUFNAHME VALUES
(134,1130,'The Medieval Ensemble of London','P.Davies/T.Davies');
INSERT INTO AUFNAHME VALUES
(135,1131,'Münchner Klaviertrio',null);
INSERT INTO AUFNAHME VALUES
(135,1132,'Münchner Klaviertrio',null);
INSERT INTO AUFNAHME VALUES
(135,1133,'Leopolder-Quartett München',null);
INSERT INTO AUFNAHME VALUES
(135,1134,'Leopolder-Quartett München',null);
INSERT INTO AUFNAHME VALUES
(136,1135,'London Festival Orchestra','Julian Armstrong');
INSERT INTO AUFNAHME VALUES
(136,1136,'London Festival Orchestra','Julian Armstrong');
INSERT INTO AUFNAHME VALUES
(137,1137,'Westminster Choir / New York Philharmonic','Leonard Bernstein');
INSERT INTO AUFNAHME VALUES
(138,1138,'Camerata Academia Salzburg','Hermann Abel');
INSERT INTO AUFNAHME VALUES
(138,1139,'Camerata Academia Salzburg','Hermann Abel');
INSERT INTO AUFNAHME VALUES
(138,1140,'Camerata Academia Salzburg','Hermann Abel');
INSERT INTO AUFNAHME VALUES
(138,1141,'Camerata Academia Salzburg','Alexander v. Pitamic');
INSERT INTO AUFNAHME VALUES
(139,1142,'Heidelberger Kammerorchester',null);
INSERT INTO AUFNAHME VALUES
(139,1143,'Heidelberger Kammerorchester',null);
INSERT INTO AUFNAHME VALUES
(139,1144,'Heidelberger Kammerorchester',null);
INSERT INTO AUFNAHME VALUES
(139,1145,'Heidelberger Kammerorchester',null);
INSERT INTO AUFNAHME VALUES
(140,1146,'Radio-Sinfonieorchester Stuttgart','Garcia Navarro');
INSERT INTO AUFNAHME VALUES
(140,1147,'Die Zagreber Solisten',null);
INSERT INTO AUFNAHME VALUES
(140,1148,null,null);
INSERT INTO AUFNAHME VALUES
(140,1149,'Radio-Sinfonieorchester Stuttgart','Garcia Navarro');
INSERT INTO AUFNAHME VALUES
(140,1150,'Radio-Sinfonieorchester Stuttgart','Garcia Navarro');
INSERT INTO AUFNAHME VALUES
(140,1151,null,null);
INSERT INTO AUFNAHME VALUES
(140,1152,'Die Zagreber Solisten',null);
INSERT INTO AUFNAHME VALUES
(141,1153,'Monteverdi Ensemble/Opernhaus Zürich','Nikolaus Harnocourt');
INSERT INTO AUFNAHME VALUES
(141,1154,'Monteverdi Ensemble/Opernhaus Zürich','Nikolaus Harnocourt');
INSERT INTO AUFNAHME VALUES
(141,1155,'Monteverdi Ensemble/Opernhaus Zürich','Nikolaus Harnocourt');
INSERT INTO AUFNAHME VALUES
(142,1156,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1157,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1158,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1159,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1160,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1161,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1162,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1163,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1164,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1165,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1166,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1167,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1168,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1169,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1170,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1171,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1172,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1173,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1174,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1175,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1176,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1177,'Ensemble für frühe Musik Augsburg',null);
INSERT INTO AUFNAHME VALUES
(142,1178,'Ensemble für frühe Musik Augsburg',null);

-- ************************************************************************

CREATE TABLE SOLIST(
	CDNR       NUMERIC(3)  NOT NULL,
	SNR        NUMERIC(4)  NOT NULL,
	NAME       VARCHAR(21) NOT NULL,
	INSTRUMENT VARCHAR(20),
	CONSTRAINT SOLIST_SCHLUESSEL
		PRIMARY KEY(CDNR, SNR, NAME),
	CONSTRAINT SOLIST_REF_AUFNAHME
		FOREIGN KEY(CDNR, SNR) REFERENCES AUFNAHME(CDNR, SNR)
);

INSERT INTO SOLIST VALUES (102,1005,'Shlomo Mintz','Violine');
INSERT INTO SOLIST VALUES (102,1006,'Shlomo Mintz','Violine');
INSERT INTO SOLIST VALUES (105,1010,'Pina Carmirelli','Violine');
INSERT INTO SOLIST VALUES (105,1011,'Pina Carmirelli','Violine');
INSERT INTO SOLIST VALUES (105,1012,'Pina Carmirelli','Violine');
INSERT INTO SOLIST VALUES (105,1013,'Pina Carmirelli','Violine');
INSERT INTO SOLIST VALUES (106,1014,'Jan Engel','Bagpipes');
INSERT INTO SOLIST VALUES (106,1014,'Max Engel','Drehleier');
INSERT INTO SOLIST VALUES (106,1015,'Kurt Moll','Bass');
INSERT INTO SOLIST VALUES (106,1016,'Jan Engel','Bagpipes');
INSERT INTO SOLIST VALUES (106,1016,'Max Engel','Drehleier');
INSERT INTO SOLIST VALUES (109,1028,'John Wallace','Trumpet');
INSERT INTO SOLIST VALUES (109,1029,'John Wallace','Trumpet');
INSERT INTO SOLIST VALUES (109,1030,'John Wallace','Trumpet');
INSERT INTO SOLIST VALUES (109,1031,'John Wallace','Trumpet');
INSERT INTO SOLIST VALUES (109,1032,'John Wallace','Trumpet');
INSERT INTO SOLIST VALUES (109,1033,'John Wallace','Trumpet');
INSERT INTO SOLIST VALUES (109,1034,'John Wallace','Trumpet');
INSERT INTO SOLIST VALUES (109,1035,'John Wallace','Trumpet');
INSERT INTO SOLIST VALUES (109,1036,'John Wallace','Trumpet');
INSERT INTO SOLIST VALUES (113,1054,'Arthur Grumiaux','Violine');
INSERT INTO SOLIST VALUES (113,1055,'Arthur Grumiaux','Violine');
INSERT INTO SOLIST VALUES (113,1056,'Arthur Grumiaux','Violine');
INSERT INTO SOLIST VALUES (113,1056,'Herman Krebbers','Violine');
INSERT INTO SOLIST VALUES (113,1057,'Arthur Grumiaux','Violine');
INSERT INTO SOLIST VALUES (113,1057,'Heinz Holliger','Oboe');
INSERT INTO SOLIST VALUES (115,1060,'Christine Whittlesey','Sopran');
INSERT INTO SOLIST VALUES (115,1060,'Wolfgang Hock','Violine');
INSERT INTO SOLIST VALUES (116,1064,'Laurence Thorstenberg','English Horn');
INSERT INTO SOLIST VALUES (119,1086,'Pinchas Zukerman','Viola');
INSERT INTO SOLIST VALUES (121,1090,'Alan Civil','Horn');
INSERT INTO SOLIST VALUES (121,1091,'Alan Civil','Horn');
INSERT INTO SOLIST VALUES (121,1092,'Alan Civil','Horn');
INSERT INTO SOLIST VALUES (121,1093,'Alan Civil','Horn');
INSERT INTO SOLIST VALUES (121,1094,'Alan Civil','Horn');
INSERT INTO SOLIST VALUES (122,1095,'Heinrich Schiff','Cello');
INSERT INTO SOLIST VALUES (122,1096,'Heinrich Schiff','Cello');
INSERT INTO SOLIST VALUES (123,1097,'Iona Brown','Violine');
INSERT INTO SOLIST VALUES (123,1098,'Iona Brown','Violine');
INSERT INTO SOLIST VALUES (123,1099,'Iona Brown','Violine');
INSERT INTO SOLIST VALUES (123,1100,'Iona Brown','Violine');
INSERT INTO SOLIST VALUES (123,1101,'Iona Brown','Violine');
INSERT INTO SOLIST VALUES (124,1102,'Krisztina Laki','Sopran');
INSERT INTO SOLIST VALUES (124,1102,'Zsuzsanna Denes','Sopran');
INSERT INTO SOLIST VALUES (124,1102,'Kurt Equiluz','Tenor');
INSERT INTO SOLIST VALUES (124,1102,'Robert Holl','Bass');
INSERT INTO SOLIST VALUES (125,1103,'Nathan Milstein','Violine');
INSERT INTO SOLIST VALUES (125,1104,'Nathan Milstein','Violine');
INSERT INTO SOLIST VALUES (128,1113,'Isabel Mourao','Piano');
INSERT INTO SOLIST VALUES (129,1115,'Lucia Popp','Sopran');
INSERT INTO SOLIST VALUES (129,1115,'Thomas Stewart','Bariton');
INSERT INTO SOLIST VALUES (129,1115,'Gottlob Frick','Bass');
INSERT INTO SOLIST VALUES (129,1116,'John van Kesteren','Tenor');
INSERT INTO SOLIST VALUES (129,1116,'Franz Crass','Bass');
INSERT INTO SOLIST VALUES (129,1116,'Fritz Strassner','Erzaehler');
INSERT INTO SOLIST VALUES (135,1134,'Wolfgang Sawallisch','Piano');
INSERT INTO SOLIST VALUES (139,1142,'Robin Williams','Oboe');
INSERT INTO SOLIST VALUES (139,1143,'Robin Williams','Oboe');
INSERT INTO SOLIST VALUES (139,1144,'Robin Williams','Oboe');
INSERT INTO SOLIST VALUES (139,1145,'Robin Williams','Oboe');
INSERT INTO SOLIST VALUES (140,1148,'Dubravka Tomsic','Piano');
INSERT INTO SOLIST VALUES (140,1151,'Dubravka Tomsic','Piano');

COMMIT;

-- ****************************************************************************

GRANT USAGE ON SCHEMA komponist_public TO student;
GRANT SELECT ON ALL TABLES IN SCHEMA komponist_public to student;

